@@ -1,4 +1,4 @@
-use x_log::XLog;
+use x_log::*;
 
 fn main() {
     XLog::new().init().unwrap();
@@ -6,8 +6,8 @@ fn main() {
     let xx = file!();
     log::trace!("This is an example message. {}", xx);
     log::debug!("This is an example message.");
-    log::info!("This is an example message.");
-    log::warn!("This is an example message.");
+    info!("This is an example message.");
+    warn!("This is an example message.");
     log::error!("This is an example message.");
 
 }
\ No newline at end of file
