@@ -1,4 +1,3 @@
-
 use log::{Level, LevelFilter, Log, Metadata, Record, SetLoggerError};
 
 use chrono::{Local, Utc};
@@ -70,9 +69,8 @@ impl Log for XLog {
 
     fn log(&self, record: &Record) {
         if self.enabled(record.metadata()) {
-
             let timestamp = {
-                match self.timezone{
+                match self.timezone {
                     Timezone::None => "".to_string(),
                     Timezone::Local => format!("{} ", Local::now().format(DEFAULT_TIME_FORMAT)),
                     Timezone::Utc => format!("{} ", Utc::now().format(DEFAULT_TIME_FORMAT)),
@@ -109,4 +107,13 @@ impl Log for XLog {
     }
 
     fn flush(&self) {}
-}
\ No newline at end of file
+}
+
+// #[macro_export]
+// macro_rules! info {
+//     ($($arg:tt)*) => {
+//         log::info!($($arg)*);
+//     };
+// }
+
+pub use log::{trace, debug, info, warn, error};
\ No newline at end of file
